==> TruetypeText-2.0.1.zip: TruetypeText/lang/en_US.php <==
<?php
$lang['addfilter'] = 'Add an image filter';
$lang['additional'] = 'Additional text';
$lang['addmirror'] = 'Add a mirror effect';
$lang['addpredefineddouble'] = 'Add a "double" style';
$lang['addpredefinedghost'] = 'Add a "ghost" style';
$lang['addpredefinedmirror'] = 'Add a "mirror" style';
$lang['addpredefinedshadow'] = 'Add a "shadow" style';
$lang['addreplacement'] = 'Add an automatic replacement';
$lang['addstyle'] = 'Add a new style';
$lang['addtext'] = 'Add text element';
$lang['addtransformation'] = 'Add a transformation';
$lang['angle'] = 'Angle';
$lang['areyousure'] = 'Are you sure ?';
$lang['Autoreplace'] = 'Automatic replacements';
$lang['back'] = 'Previous';
$lang['backgroundcolor'] = 'Background color';
$lang['blur'] = 'Blur';
$lang['cachecleared'] = 'Cache has been cleared, but preview files';
$lang['clearcache'] = 'clear cache';
$lang['color'] = 'Color';
$lang['copyelement'] = 'Copy element';
$lang['copystyle'] = 'Copy style';
$lang['downopacity'] = 'Bottom opacity';
$lang['deletefont'] = 'Delete font file';
$lang['deleteelement'] = 'Delete element';
$lang['deletereplacement'] = 'Delete automatic replacement';
$lang['deletestyle'] = 'Delete style';
$lang['deltax'] = 'Horizontal shift';
$lang['deltay'] = 'Vertical shift';
$lang['details'] = 'Details';
$lang['edge'] = 'Edge detect';
$lang['editreplacement'] = 'Edit automatic replacement';
$lang['editstyle'] = 'Edit style';
$lang['effect'] = 'Filter';
$lang['elements'] = 'Style element';
$lang['emboss'] = 'Emboss';
$lang['example'] = 'Example';
$lang['error_angle'] = 'Angle must be numerical';
$lang['error_colorformat'] = 'Color value must be like #RRGGBB or #RRGGBBTT (R: red, G: green, B: blue, T: transparency)';
$lang['error_deletefont'] = 'Unable to delete font file';
$lang['error_delta'] = 'Vertical and horizontal shifts must be numerical';
$lang['error_emptyname'] = 'You must give a name';
$lang['error_namealreadyexists'] = 'This name is already used';
$lang['error_nameisnumeric'] = 'Name must contain alphabetical text';
$lang['error_nofontfile'] = 'The first thing to do is to upload a Truetype font file';
$lang['error_maxwidth'] = 'Max width must be numerical, zero or positive';
$lang['error_noelement'] = 'A style must at least contain one text element';
$lang['error_nofilesuploaded'] = 'Unable to upload file';
$lang['error_nostyle'] = 'You must define a style first';
$lang['error_notag'] = 'HTML tag is mandatory';
$lang['error_nottffunctions'] = 'Your PHP release does not allow functions imagettftext and imagettfbbox. This module won&rsquo;t work.';
$lang['error_ratioinvalid'] = 'Ratio must be a positive numerical value';
$lang['error_size'] = 'Size must be a positive numerical value';
$lang['error_transparency'] = 'Transparency must be numerical, between 0 and 100';
$lang['error_unabletomoveelement'] = 'Unable to move element';
$lang['error_unabletosavereplacement'] = 'Unable to save automatic replacement';
$lang['error_unabletosavestyle'] = 'Unable to save style';
$lang['error_unknownelementtype'] = 'Unknown element type';
$lang['error_unknownfont'] = 'Unknown font file';
$lang['error_unknownpredefinedstyle'] = 'Unknnown predefined style';
$lang['filenumberandsize'] = 'Cache contains %s files and %s space';
$lang['fileuploaded'] = 'File has been uploaded';
$lang['flipboth'] = 'Vertical and horizontal flip';
$lang['fliphorizontal'] = 'Horizontal flip';
$lang['flipvertical'] = 'Vertical flip';
$lang['fontfile'] = 'Font file';
$lang['fontfiles'] = 'Font files';
$lang['Fonts'] = 'Font files';
$lang['format'] = 'Image format';
$lang['fulllineheight'] = 'Regular text height';
$lang['import'] = 'Import';
$lang['maxwidth'] = 'Max width';
$lang['mirror'] = 'Mirror effect';
$lang['moveelementdown'] = 'Move element down';
$lang['moveelementup'] = 'Move element up';
$lang['name'] = 'Name';
$lang['number'] = '#';
$lang['noreplacements'] = '(no replacement)';
$lang['nofontfiles'] = 'There isn&rsquo;t any Truetype font file';
$lang['nostyles'] = '(no style)';
$lang['notused'] = '(not used)';
$lang['parameters'] = 'Parameters';
$lang['pictureperword'] = 'One picture per word';
$lang['predefinedstyleadded'] = 'Style "%s" has been added';
$lang['predefinedstyles'] = 'Predefined styles';
$lang['Properties'] = 'Properties';
$lang['ratio'] = 'Height';
$lang['replacefunction'] = 'Replacement event';
$lang['replacefunctionsaved'] = 'Replacement event saved';
$lang['replacementdisabled'] = '(Disabled)';
$lang['replacemoment'] = 'When will replacement be done';
$lang['rotate90'] = '90 degree rotation';
$lang['rotate270'] = '270 degree rotation';
$lang['sampletext'] = 'Sample text';
$lang['sampletextsaved'] = 'Sample text saved';
$lang['save'] = 'Save';
$lang['size'] = 'size';
$lang['sharpen'] = 'Sharpen';
$lang['style'] = 'Style';
$lang['stylename'] = 'Name';
$lang['Styles'] = 'Styles';
$lang['stylesaved'] = 'Style has been saved';
$lang['tag'] = 'HTML tag';
$lang['tagtouse'] = 'Tag to use in template and content';
$lang['text'] = 'Text';
$lang['type'] = 'Type';
$lang['transformation'] = 'Transformation';
$lang['transparency'] = 'Transparency';
$lang['transparent'] = 'Transparent background';
$lang['unknownstyle'] = 'Unknown style';
$lang['upload'] = 'Upload a file';
$lang['upopacity'] = 'Top opacity';
$lang['usedinstyles'] = 'Styles using this font file';


$lang['description'] = 'Truetypetext module allows to display beautifull texts, with any Truetype font and various effects';
$lang['admindescription'] = 'Allows to display beautifull texts, with any Truetype font and various effects';
$lang['friendlyname'] = 'Text embellisher';
$lang['help'] = <<<EOF
	<h3>What does this module do ? ?</h3>
	<p>TruetypeText allows you to display text in a Truetype font.</p>
	<h3>How do I use it ?</h3>
	<p>You just have to insert tag <code>{cms_module module="TruetypeText" style="votre style" text="texte à enrichir"}</code> in your page.  Here are the variables to use :</p>
	<ul>
		<li><strong>text</strong> : The text you want to display. You can also use these tags :
			<ul>
				<li><strong>%title</strong> : this will display the page title</li>
				<li><strong>%menutext</strong> : this will display the menu text of the page</li>
				<li><strong>%sitename</strong> : this will display the site name</li>
				<li><strong>%description</strong> : this will display title attribute of the page</li>
			</ul>
		</li>
		<li><strong>style</strong> : name of the Truetype style to use</li>
	</ul>
	
	<h3>What is a style ?</h3>
	<p>Each style can be defined by parameters and elements :</p>
	<ul>
		<li><strong>Parameters</strong>
			<ul>
				<li><strong>Name</strong> : name of the style</li>
				<li><strong>Background color</strong> : background color of the style</li>
				<li><strong>Image format</strong> : you can choose between gif, jpg ou png</li>
				<li><strong>Regular text height</strong> : if checked, eahc text image of this style will have the same height. Useful in case of downstrokes.</li>
				<li><strong>Max width</strong> : if not null, line breaks will be done each time the text exceeds this max width.</li>
				<li><strong>One picture per word</strong> : if checked, each word will be written in a separate text image.</li>
				<li><strong>Transparent background</strong> : Only works with gif and png formats.</li>
			</ul>
		</li>
		<li><strong>Elements</strong><br />Style elements will be applied one after the other. For example : text element, then blur filter, then mirror effect.
			<ul>
				<li><strong>Text element</strong> : will write a text in a truetype font. You can choose text height, color and transparency. You can also rotate the text or shift it horizontally or vertically, which is useful when two text elements are applied.</li>
				<li><strong>Image filter</strong> : allow you to have particular effects (blur, emboss, sharpen, edge detect).</li>
				<li><strong>Mirror effect</strong> : will apply an horizontal mirror effect, like reflect on a lake.</li>
				<li><strong>Transformation</strong> : can be an horizontal flip, a vertical flip, or both flips, and also a rotation (90 degree and 270 degree)</li>
			</ul>
		</li>
	</ul>
	
	<h3>automatic replacement</h3>
	<p>TruetypeText allows you to automatically replace some parts of the content by a truetype image. You have to choose when this replacement will occur :
	<ul>
		<li><strong>ContentPostCompile</strong> (recommended) : Called right after smarty is done processing and ready to head off to the cache</li>
		<li><strong>ContentPostRender</strong> : Called after content is sent to smarty for processing and right before display. Cached content will still call this function before display, but it is called EVERY time a page is requested.</li>
		<li><strong>Disabled</strong> : speaks for itself</li>
	</ul>
	</p>

	<p>You can create several. Each one will contain those elements :
	<ul>
		<li><strong>Tag</strong> : an html tag (for example : "h1", "h2", "em", "strong"). For example, if you choose h1 each first level title element will be replaced</li>
		<li><strong>Additional text</strong> : an html attribute (sample : "class='beautifultext'"). This allows you to restrain the replacement to certain class for example.</li>
		<li><strong>Style</strong> : a TruetypeText style to use.</li>
	</ul>
	</p>
EOF;
?>

==> TruetypeText2.2.zip: TruetypeText/lang/en_US.php <==
<?php
$lang['addfilter'] = 'Add an image filter';
$lang['additional'] = 'Additional text';
$lang['addmirror'] = 'Add a mirror effect';
$lang['addpredefineddouble'] = 'Add a "double" style';
$lang['addpredefinedghost'] = 'Add a "ghost" style';
$lang['addpredefinedmirror'] = 'Add a "mirror" style';
$lang['addpredefinedshadow'] = 'Add a "shadow" style';
$lang['addreplacement'] = 'Add an automatic replacement';
$lang['addstyle'] = 'Add a new style';
$lang['addtext'] = 'Add text element';
$lang['addtransformation'] = 'Add a transformation';
$lang['angle'] = 'Angle';
$lang['areyousure'] = 'Are you sure ?';
$lang['Autoreplace'] = 'Automatic replacements';
$lang['back'] = 'Previous';
$lang['backgroundcolor'] = 'Background color';
$lang['blur'] = 'Blur';
$lang['cachecleared'] = 'Cache has been cleared, but preview files';
$lang['clearcache'] = 'clear cache';
$lang['color'] = 'Color';
$lang['copyelement'] = 'Copy element';
$lang['copystyle'] = 'Copy style';
$lang['downopacity'] = 'Bottom opacity';
$lang['deletefont'] = 'Delete font file';
$lang['deleteelement'] = 'Delete element';
$lang['deletereplacement'] = 'Delete automatic replacement';
$lang['deletestyle'] = 'Delete style';
$lang['deltax'] = 'Horizontal shift';
$lang['deltay'] = 'Vertical shift';
$lang['details'] = 'Details';
$lang['edge'] = 'Edge detect';
$lang['editreplacement'] = 'Edit automatic replacement';
$lang['editstyle'] = 'Edit style';
$lang['effect'] = 'Filter';
$lang['elements'] = 'Style element';
$lang['emboss'] = 'Emboss';
$lang['example'] = 'Example';
$lang['error_angle'] = 'Angle must be numerical';
$lang['error_colorformat'] = 'Color value must be like #RRGGBB or #RRGGBBTT (R: red, G: green, B: blue, T: transparency)';
$lang['error_deletefont'] = 'Unable to delete font file';
$lang['error_delta'] = 'Vertical and horizontal shifts must be numerical';
$lang['error_emptyname'] = 'You must give a name';
$lang['error_namealreadyexists'] = 'This name is already used';
$lang['error_nameisnumeric'] = 'Name must contain alphabetical text';
$lang['error_nofontfile'] = 'The first thing to do is to upload a Truetype font file';
$lang['error_maxwidth'] = 'Max width must be numerical, zero or positive';
$lang['error_noelement'] = 'A style must at least contain one text element';
$lang['error_nofilesuploaded'] = 'Unable to upload file';
$lang['error_nostyle'] = 'You must define a style first';
$lang['error_notag'] = 'HTML tag is mandatory';
$lang['error_nottffunctions'] = 'Your PHP release does not allow functions imagettftext and imagettfbbox. This module won&rsquo;t work.';
$lang['error_ratioinvalid'] = 'Ratio must be a positive numerical value';
$lang['error_size'] = 'Size must be a positive numerical value';
$lang['error_transparency'] = 'Transparency must be numerical, between 0 and 100';
$lang['error_unabletomoveelement'] = 'Unable to move element';
$lang['error_unabletosavereplacement'] = 'Unable to save automatic replacement';
$lang['error_unabletosavestyle'] = 'Unable to save style';
$lang['error_unknownelementtype'] = 'Unknown element type';
$lang['error_unknownfont'] = 'Unknown font file';
$lang['error_unknownpredefinedstyle'] = 'Unknnown predefined style';
$lang['filenumberandsize'] = 'Cache contains %s files and %s space';
$lang['fileuploaded'] = 'File has been uploaded';
$lang['flipboth'] = 'Vertical and horizontal flip';
$lang['fliphorizontal'] = 'Horizontal flip';
$lang['flipvertical'] = 'Vertical flip';
$lang['fontfile'] = 'Font file';
$lang['fontfiles'] = 'Font files';
$lang['Fonts'] = 'Font files';
$lang['format'] = 'Image format';
$lang['fulllineheight'] = 'Regular text height';
$lang['import'] = 'Import';
$lang['maxwidth'] = 'Max width';
$lang['mirror'] = 'Mirror effect';
$lang['moveelementdown'] = 'Move element down';
$lang['moveelementup'] = 'Move element up';
$lang['name'] = 'Name';
$lang['number'] = '#';
$lang['noreplacements'] = '(no replacement)';
$lang['nofontfiles'] = 'There isn&rsquo;t any Truetype font file';
$lang['nostyles'] = '(no style)';
$lang['notused'] = '(not used)';
$lang['parameters'] = 'Parameters';
$lang['pictureperword'] = 'One picture per word';
$lang['predefinedstyleadded'] = 'Style "%s" has been added';
$lang['predefinedstyles'] = 'Predefined styles';
$lang['Properties'] = 'Properties';
$lang['ratio'] = 'Height';
$lang['replacefunction'] = 'Replacement event';
$lang['replacefunctionsaved'] = 'Replacement event saved';
$lang['replacementdisabled'] = '(Disabled)';
$lang['replacemoment'] = 'When will replacement be done';
$lang['rotate90'] = '90 degree rotation';
$lang['rotate270'] = '270 degree rotation';
$lang['sampletext'] = 'Sample text';
$lang['sampletextsaved'] = 'Sample text saved';
$lang['save'] = 'Save';
$lang['size'] = 'size';
$lang['sharpen'] = 'Sharpen';
$lang['style'] = 'Style';
$lang['stylename'] = 'Name';
$lang['Styles'] = 'Styles';
$lang['stylesaved'] = 'Style has been saved';
$lang['tag'] = 'HTML tag';
$lang['tagtouse'] = 'Tag to use in template and content';
$lang['text'] = 'Text';
$lang['type'] = 'Type';
$lang['transformation'] = 'Transformation';
$lang['transparency'] = 'Transparency';
$lang['transparent'] = 'Transparent background';
$lang['unknownstyle'] = 'Unknown style';
$lang['upload'] = 'Upload a file';
$lang['upopacity'] = 'Top opacity';
$lang['usedinstyles'] = 'Styles using this font file';


$lang['description'] = 'Truetypetext module allows to display beautifull texts, with any Truetype font and various effects';
$lang['admindescription'] = 'Allows to display beautifull texts, with any Truetype font and various effects';
$lang['friendlyname'] = 'Text embellisher';
$lang['usage'] = 'Usage';
$lang['styles'] = 'Styles';
$lang['auto_replacement'] = 'Auto replacement';
$lang['about'] = 'About';
$lang['help_usage'] = '<h3>What does this module do?</h3>
	<p>TruetypeText allows you to display text in a Truetype font.</p>
	<h3>How do I use it ?</h3>
	<p>You just have to insert tag <code>{cms_module module="TruetypeText" style="your style" text="your text"}</code> in your page. The accepted parameters are listed below.</p>';
$lang['help_styles'] = '<h3>What is a style?</h3>
	<p>Each style can be defined by parameters and elements :</p>
	<ul>
		<li><strong>Parameters</strong>
			<ul>
				<li><strong>Name</strong> : name of the style</li>
				<li><strong>Background color</strong> : background color of the style</li>
				<li><strong>Image format</strong> : you can choose between gif, jpg ou png</li>
				<li><strong>Regular text height</strong> : if checked, eahc text image of this style will have the same height. Useful in case of downstrokes.</li>
				<li><strong>Max width</strong> : if not null, line breaks will be done each time the text exceeds this max width.</li>
				<li><strong>One picture per word</strong> : if checked, each word will be written in a separate text image.</li>
				<li><strong>Transparent background</strong> : Only works with gif and png formats.</li>
			</ul>
		</li>
		<li><strong>Elements</strong><br />Style elements will be applied one after the other. For example : text element, then blur filter, then mirror effect.
			<ul>
				<li><strong>Text element</strong> : will write a text in a truetype font. You can choose text height, color and transparency. You can also rotate the text or shift it horizontally or vertically, which is useful when two text elements are applied.</li>
				<li><strong>Image filter</strong> : allow you to have particular effects (blur, emboss, sharpen, edge detect).</li>
				<li><strong>Mirror effect</strong> : will apply an horizontal mirror effect, like reflect on a lake.</li>
				<li><strong>Transformation</strong> : can be an horizontal flip, a vertical flip, or both flips, and also a rotation (90 degree and 270 degree)</li>
			</ul>
		</li>
	</ul>';
$lang['help_auto_replacement'] = '<h3>Auto replacement</h3>
	<p>TruetypeText allows you to automatically replace some parts of the content by a truetype image. You have to choose when this replacement will occur :</p>
	<ul>
		<li><strong>ContentPostCompile</strong> (recommended) : Called right after smarty is done processing and ready to head off to the cache</li>
		<li><strong>ContentPostRender</strong> : Called after content is sent to smarty for processing and right before display. Cached content will still call this function before display, but it is called EVERY time a page is requested.</li>
		<li><strong>Disabled</strong> : speaks for itself</li>
	</ul>
	<p>You can create several. Each one will contain those elements :</p>
	<ul>
		<li><strong>Tag</strong> : an html tag (for example : "h1", "h2", "em", "strong"). For example, if you choose h1 each first level title element will be replaced</li>
		<li><strong>Additional text</strong> : an html attribute (sample: class="beautifultext"). This allows you to restrain the replacement to certain class for example.</li>
		<li><strong>Style</strong> : a TruetypeText style to use.</li>
	</ul>';
$lang['help_about'] = '<h3>About</h3>
	<p>The module is originally written by Damien Gauthier. At the moment Jonathan Schmid is the only active developer.<br />
	If you find any bugs please feel free to submit a bug report <a href="http://dev.cmsmadesimple.org/bug/list/161" target="_blank">here</a> or for any good ideas consider submiting a feature request <a href="http://dev.cmsmadesimple.org/feature_request/list/161" target="_blank">here</a>. <br />
	Please keep in mind that developers do have their daily jobs which means that feature requests are considered and done as time allows. If you need a feature really badly consider contacting one of the developers for a sponsored development.
	</p>
	<h3>Team</h3>
	<ul>
		<li>Jonathan Schmid (Foaly*) hi@jonathanschmid.de <br />www.jonathanschmid.de</li>
		<li>Damien Gauthier (dam) trigau@free.fr</li>
		<li>Gaute Sandvik (gaute) gaute_sandvik@c2i.net</li>
	</ul>';
$lang['help_param_text'] = 'The text you want to display. You can also use these tags:
	<ul>
		<li><strong>%title</strong> : this will display the page title</li>
		<li><strong>%menutext</strong> : this will display the menu text of the page</li>
		<li><strong>%sitename</strong> : this will display the site name</li>
		<li><strong>%description</strong> : this will display title attribute of the page</li>
	</ul>';
$lang['help_param_style'] = 'name of the Truetype style to use.';
$lang['help_param_hidealttext'] = 'set to "1" if you want to hide alternate text in img tag.';
$lang['help_param_moretext'] = 'any text that you want to be added at the end of the img tag. For example : class="myclass".';
$lang['help_param_imagesrc'] = 'only image src will be returned if set to true. Overwrites "one picture per word" parameter.';
?>
